@@ -223,7 +223,8 @@ def getAudiencesClass(
         django_max_func,
         audience_ttl,
         audience_domains,
-        default_audience_id_prefix):
+        default_audience_id_prefix,
+        allowed_audience_fields):
 
     cls = Audiences
     cls.domain = domain
@@ -234,5 +235,6 @@ def getAudiencesClass(
     cls.audience_domains = audience_domains
     cls.default_audience_id_prefix = default_audience_id_prefix
     cls.django_max_func = django_max_func
+    cls.allowed_audience_fields = allowed_audience_fields
 
     return cls
\ No newline at end of file
